# Copyright (c) ModelScope Contributors. All rights reserved.
"""
Sirchmunk Command Line Interface.

Provides CLI commands for initialization, configuration, server management,
and search operations.
"""

from .cli import run_cmd

__all__ = ["run_cmd"]
