# Copyright (c) ModelScope Contributors. All rights reserved.
from dataclasses import dataclass
from typing import List

from .knowledge import KnowledgeCluster
from .request import Request
from .response import Response


@dataclass
class Context:
    """
    Represents the context of an agentic search operation.
    """

    # The request made by the user
    request: Request

    # The response generated by the agentic search operation
    response: Response = None

    # A list of knowledge clusters related to the search operation
    related_knowledge: List[KnowledgeCluster] = None

    def __post_init__(self): ...
